summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorRomain Guy <romainguy@android.com>2010-01-08 15:06:57 -0800
committerRomain Guy <romainguy@android.com>2010-01-08 15:11:50 -0800
commit00bed653ca0ba41de3b20508f53254c78cac1f4a (patch)
treeffd7afec49ee2fd5aa8d6af63f00f5d84de94a67
parentfb3c916e6e02905c2f30bfea80a838825b3f42e6 (diff)
downloadIM-00bed653ca0ba41de3b20508f53254c78cac1f4a.tar.gz
Deprecate fill_parent and introduce match_parent.
Bug: #2361749.
-rw-r--r--res/layout/account_activity.xml14
-rw-r--r--res/layout/account_view.xml10
-rw-r--r--res/layout/add_contact_activity.xml16
-rw-r--r--res/layout/blocked_contact_view.xml12
-rw-r--r--res/layout/blocked_contacts_activity.xml12
-rw-r--r--res/layout/chat_switcher_dialog.xml10
-rw-r--r--res/layout/chat_switcher_item.xml2
-rw-r--r--res/layout/chat_view.xml34
-rw-r--r--res/layout/contact_list_filter_view.xml8
-rw-r--r--res/layout/contact_list_view.xml14
-rw-r--r--res/layout/contact_presence_activity.xml18
-rw-r--r--res/layout/contact_view.xml10
-rw-r--r--res/layout/contacts_picker_activity.xml16
-rw-r--r--res/layout/group_view.xml2
-rw-r--r--res/layout/imglist_item.xml4
-rw-r--r--res/layout/new_message_item.xml4
-rw-r--r--res/layout/preference_activity.xml12
-rw-r--r--res/layout/signing_in_activity.xml8
-rw-r--r--res/layout/simple_input_activity.xml6
-rw-r--r--res/layout/smiley_menu_item.xml2
-rw-r--r--src/com/android/im/app/SimpleInputActivity.java4
21 files changed, 109 insertions, 109 deletions
diff --git a/res/layout/account_activity.xml b/res/layout/account_activity.xml
index b911f3c..9387074 100644
--- a/res/layout/account_activity.xml
+++ b/res/layout/account_activity.xml
@@ -18,8 +18,8 @@
*/
-->
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:orientation="vertical"
android:padding="10dip">
@@ -30,7 +30,7 @@
<EditText android:id="@+id/edtName"
android:completionThreshold="1"
android:selectAllOnFocus="true"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:inputType="text" />
@@ -40,12 +40,12 @@
android:text="@string/label_password" />
<EditText android:id="@+id/edtPass"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:selectAllOnFocus="true"
android:inputType="textPassword"/>
- <LinearLayout android:layout_width="fill_parent"
+ <LinearLayout android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="horizontal">
<LinearLayout android:layout_width="wrap_content"
@@ -65,8 +65,8 @@
android:text="@string/keep_me_signed_in" />
</LinearLayout>
- <LinearLayout android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ <LinearLayout android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:layout_weight="1.0"
android:gravity="center_vertical|right"
android:orientation="horizontal">
diff --git a/res/layout/account_view.xml b/res/layout/account_view.xml
index 411c844..5acee3b 100644
--- a/res/layout/account_view.xml
+++ b/res/layout/account_view.xml
@@ -20,7 +20,7 @@
<com.android.im.app.ProviderListItem
xmlns:android="http://schemas.android.com/apk/res/android"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="?android:attr/listPreferredItemHeight">
<ImageView
@@ -37,7 +37,7 @@
android:orientation="horizontal"
android:layout_weight="1"
android:layout_width="0dip"
- android:layout_height="fill_parent">
+ android:layout_height="match_parent">
<LinearLayout
android:orientation="vertical"
@@ -48,7 +48,7 @@
<LinearLayout
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content">
<TextView android:id="@+id/providerName"
@@ -58,7 +58,7 @@
android:singleLine="true"
android:layout_weight="1.0"
android:ellipsize="marquee"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" />
<TextView android:id="@+id/conversations"
android:textAppearance="?android:attr/textAppearanceMedium"
@@ -75,7 +75,7 @@
android:textColor="@color/landing_page_text"
android:ellipsize="marquee"
android:singleLine="true"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"/>
</LinearLayout>
<ImageView
diff --git a/res/layout/add_contact_activity.xml b/res/layout/add_contact_activity.xml
index d7aa87c..4f6f5df 100644
--- a/res/layout/add_contact_activity.xml
+++ b/res/layout/add_contact_activity.xml
@@ -18,39 +18,39 @@
*/
-->
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:orientation="vertical">
<TextView android:id="@+id/input_contact_label"
android:layout_marginTop="10dip"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:text="@string/input_contact_label" />
<MultiAutoCompleteTextView android:id="@+id/email"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" />
<TextView android:id="@+id/choose_list_label"
android:layout_marginTop="10dip"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:text="@string/choose_list_label" />
<Spinner android:id="@+id/choose_list"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:drawSelectorOnTop="true"
android:prompt="@string/choose_list_label" />
<TextView android:layout_marginTop="10dip"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:textSize="24sp"
android:text="@string/invite_instruction" />
- <LinearLayout android:layout_width="fill_parent"
+ <LinearLayout android:layout_width="match_parent"
android:layout_height="wrap_content"
android:gravity="right">
diff --git a/res/layout/blocked_contact_view.xml b/res/layout/blocked_contact_view.xml
index ce23a18..7b26fd5 100644
--- a/res/layout/blocked_contact_view.xml
+++ b/res/layout/blocked_contact_view.xml
@@ -21,7 +21,7 @@
<view xmlns:android="http://schemas.android.com/apk/res/android"
class="com.android.im.app.BlockedContactView"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:minHeight="?android:attr/listPreferredItemHeight"
android:paddingLeft="9dip"
@@ -33,8 +33,8 @@
android:layout_height="60dip">
<ImageView android:id="@+id/avatar"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:padding="2dip"
android:scaleType="fitCenter" />
@@ -50,19 +50,19 @@
android:orientation="vertical"
android:paddingLeft="9dip"
android:layout_gravity="center_vertical"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content">
<TextView android:id="@+id/line1"
android:maxLines="1"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_weight="1"
android:layout_height="wrap_content"
android:textAppearance="?android:attr/textAppearanceLarge" />
<TextView android:id="@+id/line2"
android:maxLines="1"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:textAppearance="?android:attr/textAppearanceMedium" />
diff --git a/res/layout/blocked_contacts_activity.xml b/res/layout/blocked_contacts_activity.xml
index 8acb900..499566b 100644
--- a/res/layout/blocked_contacts_activity.xml
+++ b/res/layout/blocked_contacts_activity.xml
@@ -18,21 +18,21 @@
*/
-->
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:orientation="vertical">
<TextView android:id="@android:id/empty"
android:textAppearance="?android:attr/textAppearanceSmall"
android:textStyle="bold"
android:gravity="center_vertical|center_horizontal"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:focusable="false"
android:text="@string/no_blocked_contact" />
<ListView android:id="@android:id/list"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent" />
+ android:layout_width="match_parent"
+ android:layout_height="match_parent" />
</LinearLayout>
diff --git a/res/layout/chat_switcher_dialog.xml b/res/layout/chat_switcher_dialog.xml
index cbfa002..24a9c05 100644
--- a/res/layout/chat_switcher_dialog.xml
+++ b/res/layout/chat_switcher_dialog.xml
@@ -19,19 +19,19 @@
-->
<RelativeLayout xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="112dip" >
<HorizontalScrollView
android:scrollbars="none"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent">
+ android:layout_width="match_parent"
+ android:layout_height="match_parent">
<LinearLayout
android:orientation="horizontal"
android:id="@+id/pseudogallery"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent" >
+ android:layout_width="match_parent"
+ android:layout_height="match_parent" >
</LinearLayout>
</HorizontalScrollView>
diff --git a/res/layout/chat_switcher_item.xml b/res/layout/chat_switcher_item.xml
index fd3788f..169cd37 100644
--- a/res/layout/chat_switcher_item.xml
+++ b/res/layout/chat_switcher_item.xml
@@ -21,7 +21,7 @@
android:background="@drawable/dashboard_highlight"
android:layout_gravity="center_horizontal"
android:layout_width="92dip"
- android:layout_height="fill_parent">
+ android:layout_height="match_parent">
<!-- avatar -->
<ImageView android:id="@+id/avatar"
diff --git a/res/layout/chat_view.xml b/res/layout/chat_view.xml
index 0b76029..e7ed971 100644
--- a/res/layout/chat_view.xml
+++ b/res/layout/chat_view.xml
@@ -22,12 +22,12 @@
android:id="@+id/chatView"
android:orientation="vertical"
android:background="#ffffffff"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent">
+ android:layout_width="match_parent"
+ android:layout_height="match_parent">
<!-- The title bar -->
<LinearLayout style="?android:attr/windowTitleBackgroundStyle"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:gravity="center_vertical"
android:orientation="horizontal">
@@ -40,7 +40,7 @@
<TextView android:id="@+id/title"
style="?android:attr/windowTitleStyle"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_weight="1"
android:background="@null"
@@ -49,13 +49,13 @@
android:layout_marginRight="20dip" />
</LinearLayout>
- <View android:layout_width="fill_parent"
+ <View android:layout_width="match_parent"
android:layout_height="1dip"
android:background="#ff202020" />
<ListView android:id="@+id/history"
android:cacheColorHint="#00000000"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="0dip"
android:layout_weight="1"
android:drawSelectorOnTop="true"
@@ -65,7 +65,7 @@
android:scrollbarAlwaysDrawVerticalTrack="true" />
<LinearLayout android:id="@+id/invitationPanel"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_gravity="bottom"
android:orientation="vertical"
@@ -73,12 +73,12 @@
android:background="@drawable/text_divider_horizontal">
<TextView android:id="@+id/txtInvitation"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:textColor="#ffad45d6"
android:text="@string/invitation_prompt" />
- <LinearLayout android:layout_width="fill_parent"
+ <LinearLayout android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="horizontal">
@@ -96,7 +96,7 @@
</LinearLayout>
<LinearLayout android:id="@+id/subscription"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_gravity="bottom"
android:orientation="vertical"
@@ -104,12 +104,12 @@
android:background="@drawable/text_divider_horizontal">
<TextView android:id="@+id/txtSubscription"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:textColor="#ffad45d6"
android:text="@string/subscription_prompt" />
- <LinearLayout android:layout_width="fill_parent"
+ <LinearLayout android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="horizontal">
@@ -127,7 +127,7 @@
</LinearLayout>
<LinearLayout android:id="@+id/warning"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_gravity="bottom"
android:orientation="horizontal"
@@ -136,11 +136,11 @@
<ImageView android:id="@+id/warningIcon"
android:layout_width="wrap_content"
- android:layout_height="fill_parent"
+ android:layout_height="match_parent"
android:src="@drawable/ic_im_message_not_sent" />
<TextView android:id="@+id/warningText"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:paddingLeft="5dip"
android:textColor="#ffff0000"
@@ -148,7 +148,7 @@
</LinearLayout>
- <LinearLayout android:layout_width="fill_parent"
+ <LinearLayout android:layout_width="match_parent"
android:layout_height="wrap_content"
android:baselineAligned="false"
android:orientation="horizontal"
@@ -166,7 +166,7 @@
<Button android:id="@+id/btnSend"
android:layout_width="wrap_content"
- android:layout_height="fill_parent"
+ android:layout_height="match_parent"
android:text="@string/send" />
</LinearLayout>
</com.android.im.app.ChatView>
diff --git a/res/layout/contact_list_filter_view.xml b/res/layout/contact_list_filter_view.xml
index f160196..30112d4 100644
--- a/res/layout/contact_list_filter_view.xml
+++ b/res/layout/contact_list_filter_view.xml
@@ -19,13 +19,13 @@
-->
<com.android.im.app.ContactListFilterView
xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:id="@+id/contactFilterView"
android:orientation="vertical">
<ListView android:id="@+id/filteredList"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent" />
+ android:layout_width="match_parent"
+ android:layout_height="match_parent" />
</com.android.im.app.ContactListFilterView>
diff --git a/res/layout/contact_list_view.xml b/res/layout/contact_list_view.xml
index 619dff1..bd2d816 100644
--- a/res/layout/contact_list_view.xml
+++ b/res/layout/contact_list_view.xml
@@ -18,15 +18,15 @@
*/
-->
<com.android.im.app.ContactListView xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:id="@+id/contactListView"
android:orientation="vertical">
<com.android.im.app.UserPresenceView
android:id="@+id/userPresence"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="64dip"
android:layout_centerVertical="true"
android:paddingTop="9dip"
@@ -37,7 +37,7 @@
<LinearLayout
android:layout_width="wrap_content"
- android:layout_height="fill_parent"
+ android:layout_height="match_parent"
android:layout_gravity="center_vertical">
<ImageButton android:id="@+id/statusDropDownButton"
@@ -63,7 +63,7 @@
android:visibility="gone"/>
<TextView android:id="@+id/statusView"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:gravity="center_vertical"
android:paddingTop="5dip"
@@ -75,8 +75,8 @@
</com.android.im.app.UserPresenceView>
<ExpandableListView android:id="@+id/contactsList"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:nextFocusUp="@id/statusDropDownButton" />
</com.android.im.app.ContactListView>
diff --git a/res/layout/contact_presence_activity.xml b/res/layout/contact_presence_activity.xml
index 5cccba6..b0fb992 100644
--- a/res/layout/contact_presence_activity.xml
+++ b/res/layout/contact_presence_activity.xml
@@ -18,7 +18,7 @@
*/
-->
<ScrollView xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" >
<LinearLayout
@@ -26,7 +26,7 @@
android:paddingTop="15dip"
android:paddingRight="15dip"
android:paddingBottom="15dip"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="vertical" >
@@ -37,7 +37,7 @@
android:background="@drawable/picture_frame_background" />
<TextView android:id="@+id/labelName"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_marginTop="12dip"
android:textStyle="bold"
@@ -45,11 +45,11 @@
android:text="@string/label_username" />
<TextView android:id="@+id/txtName"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"/>
<TextView android:id="@+id/labelStatus"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_marginTop="8dip"
android:textStyle="bold"
@@ -57,11 +57,11 @@
android:text="@string/label_status" />
<TextView android:id="@+id/txtStatus"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" />
<TextView android:id="@+id/txtStatusText"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_marginRight="8dip"
android:layout_marginTop="4dip"
@@ -70,7 +70,7 @@
android:textStyle="italic" />
<TextView android:id="@+id/labelClientType"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_marginTop="8dip"
android:textStyle="bold"
@@ -78,7 +78,7 @@
android:text="@string/label_client_type" />
<TextView android:id="@+id/txtClientType"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" />
</LinearLayout>
diff --git a/res/layout/contact_view.xml b/res/layout/contact_view.xml
index 00dc0b9..51ec032 100644
--- a/res/layout/contact_view.xml
+++ b/res/layout/contact_view.xml
@@ -21,7 +21,7 @@
<view xmlns:android="http://schemas.android.com/apk/res/android"
class="com.android.im.app.ContactView"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="?android:attr/listPreferredItemHeight"
android:paddingTop="2dip"
android:paddingBottom="2dip"
@@ -31,7 +31,7 @@
<RelativeLayout
android:id="@+id/contactInfo"
android:layout_width="0dip"
- android:layout_height="fill_parent"
+ android:layout_height="match_parent"
android:layout_weight="1"
android:layout_marginRight="5dip"
android:paddingLeft="6dip">
@@ -48,13 +48,13 @@
<LinearLayout
android:orientation="vertical"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:layout_toLeftOf="@id/presence"
android:layout_centerVertical="true">
<LinearLayout android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content">
<TextView android:id="@+id/line1"
@@ -77,7 +77,7 @@
<TextView android:id="@+id/line2"
android:singleLine="true"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:textAppearance="?android:attr/textAppearanceSmall"
android:ellipsize="marquee"/>
diff --git a/res/layout/contacts_picker_activity.xml b/res/layout/contacts_picker_activity.xml
index d47047c..733daac 100644
--- a/res/layout/contacts_picker_activity.xml
+++ b/res/layout/contacts_picker_activity.xml
@@ -19,24 +19,24 @@
-->
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
android:orientation="vertical"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent" >
+ android:layout_width="match_parent"
+ android:layout_height="match_parent" >
<EditText android:id="@+id/filter"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:hint="@string/contact_filter_hint"/>
<RelativeLayout
android:layout_weight="1"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="0dip">
<ListView android:id="@android:id/list"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"/>
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"/>
<TextView android:id="@android:id/empty"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:textAppearance="?android:attr/textAppearanceSmall"
android:gravity="top|center_horizontal"
android:focusable="false"
diff --git a/res/layout/group_view.xml b/res/layout/group_view.xml
index 6bf5768..991d98c 100644
--- a/res/layout/group_view.xml
+++ b/res/layout/group_view.xml
@@ -20,7 +20,7 @@
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="?android:attr/listPreferredItemHeight"
android:paddingLeft="?android:attr/expandableListPreferredItemPaddingLeft">
diff --git a/res/layout/imglist_item.xml b/res/layout/imglist_item.xml
index a210dd9..9f98bca 100644
--- a/res/layout/imglist_item.xml
+++ b/res/layout/imglist_item.xml
@@ -20,12 +20,12 @@
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="?android:attr/listPreferredItemHeight"
android:gravity="center_vertical" >
<ImageView android:id="@+id/separator"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:paddingTop="3dip"
android:paddingBottom="3dip"
diff --git a/res/layout/new_message_item.xml b/res/layout/new_message_item.xml
index a662630..49aea7f 100644
--- a/res/layout/new_message_item.xml
+++ b/res/layout/new_message_item.xml
@@ -20,12 +20,12 @@
<view xmlns:android="http://schemas.android.com/apk/res/android"
class="com.android.im.app.MessageView"
android:orientation="vertical"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" >
<TextView android:id="@+id/message"
android:textAppearance="?android:attr/textAppearanceMedium"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" />
</view>
diff --git a/res/layout/preference_activity.xml b/res/layout/preference_activity.xml
index d8b6c06..01b8474 100644
--- a/res/layout/preference_activity.xml
+++ b/res/layout/preference_activity.xml
@@ -18,11 +18,11 @@
*/
-->
<ScrollView xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" >
<RelativeLayout
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" >
<TextView android:id="@+id/tvDataChannel"
@@ -126,7 +126,7 @@
</RadioGroup>
<LinearLayout android:id="@+id/host"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="horizontal"
android:layout_below="@+id/rgCirChannel"
@@ -141,7 +141,7 @@
<EditText android:id="@+id/etHost"
android:autoText="false"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:singleLine="true"
android:textAppearance="?android:attr/textAppearanceSmall"
@@ -150,7 +150,7 @@
</LinearLayout>
<LinearLayout android:id="@+id/msisdn"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="horizontal"
android:layout_below="@+id/host"
@@ -165,7 +165,7 @@
<EditText android:id="@+id/etMsisdn"
android:autoText="false"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:singleLine="true"
android:textAppearance="?android:attr/textAppearanceSmall"
diff --git a/res/layout/signing_in_activity.xml b/res/layout/signing_in_activity.xml
index add1e64..c6ae527 100644
--- a/res/layout/signing_in_activity.xml
+++ b/res/layout/signing_in_activity.xml
@@ -19,18 +19,18 @@
-->
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
android:orientation="vertical"
- android:layout_width="fill_parent"
- android:layout_height="fill_parent"
+ android:layout_width="match_parent"
+ android:layout_height="match_parent"
android:gravity="center_vertical">
<ImageView android:id="@+id/splashscr"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:scaleType="fitCenter"/>
<LinearLayout
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:paddingTop="10dip"
android:gravity="center_horizontal">
diff --git a/res/layout/simple_input_activity.xml b/res/layout/simple_input_activity.xml
index 80a5a77..bf9d888 100644
--- a/res/layout/simple_input_activity.xml
+++ b/res/layout/simple_input_activity.xml
@@ -18,17 +18,17 @@
*/
-->
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:orientation="vertical">
<TextView android:id="@+id/prompt"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content" />
<EditText android:id="@+id/edit"
android:autoText="false"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="wrap_content"
android:singleLine="true" />
diff --git a/res/layout/smiley_menu_item.xml b/res/layout/smiley_menu_item.xml
index 61d76e0..be27eec 100644
--- a/res/layout/smiley_menu_item.xml
+++ b/res/layout/smiley_menu_item.xml
@@ -18,7 +18,7 @@
<LinearLayout xmlns:android="http://schemas.android.com/apk/res/android"
android:orientation="horizontal"
- android:layout_width="fill_parent"
+ android:layout_width="match_parent"
android:layout_height="?android:attr/listPreferredItemHeight">
<ImageView android:id="@+id/smiley_icon"
diff --git a/src/com/android/im/app/SimpleInputActivity.java b/src/com/android/im/app/SimpleInputActivity.java
index 84e3bad..d4e239e 100644
--- a/src/com/android/im/app/SimpleInputActivity.java
+++ b/src/com/android/im/app/SimpleInputActivity.java
@@ -90,9 +90,9 @@ public class SimpleInputActivity extends Activity {
}
});
// XXX Hack from GoogleLogin.java. The android:layout_width="fill_parent"
// defined in the layout xml doesn't seem to work for LinearLayout.
- getWindow().setLayout(LayoutParams.FILL_PARENT, LayoutParams.WRAP_CONTENT);
+ getWindow().setLayout(LayoutParams.MATCH_PARENT, LayoutParams.WRAP_CONTENT);
}
}
@@ -90,9 +90,9 @@ public class SimpleInputActivity extends Activity {
}
});
- // XXX Hack from GoogleLogin.java. The android:layout_width="fill_parent"
+ // XXX Hack from GoogleLogin.java. The android:layout_width="match_parent"
// defined in the layout xml doesn't seem to work for LinearLayout.